# Beamline Experiment Control (BEC) documentation

<br><br>

````{grid} 3
:gutter: 5

```{grid-item-card}  Introduction
:link: introduction
:link-type: ref

General information about BEC.
```

```{grid-item-card}  User
:link: user
:link-type: ref

Information for users of BEC.
```

```{grid-item-card}  Developer
:link: developer
:link-type: ref

Information for developers of BEC.
```
````


```{toctree}
---
numbered: true
maxdepth: 2
---

introduction/introduction
user/user
developer/developer



